@@ -14,6 +14,7 @@ import tarfile
 
 import yaml
 
+from diadmin.utils.utils import add_defaultsuffix, toggle_mockapi
 from diadmin.vctl_cmds.login import di_login
 from diadmin.vctl_cmds.vrep import get_all_files, read_file, export_artifact, solution_from_repo
 from diadmin.vctl_cmds.solution import download_solution
@@ -37,7 +38,7 @@ def main() :
     #
     # command line args
     #
-    achoices = ['operators','graphs','dockerfiles','all','*','solution']
+    achoices = ['operators','graphs','dockerfiles','menu','all','*','solution']
     description =  "Downloads operators, pipelines or solution to local from SAP Data Intelligence to local file system.\nPre-requiste: vctl."
     parser = argparse.ArgumentParser(description=description)
     parser.add_argument('-c','--config', help = 'Specifies yaml-config file',default='config_demo.yaml')
@@ -66,9 +67,7 @@ def main() :
 
     config_file = 'config.yaml'
     if args.config:
-        config_file = args.config
-        if not re.match('.+\.yaml',config_file) :
-            config_file += '.yaml'
+        config_file = add_defaultsuffix(args.config,'yaml')
 
     with open(config_file) as yamls:
         params = yaml.safe_load(yamls)
@@ -90,6 +89,8 @@ def main() :
     if args.artifact_type == 'solution' :
         file = path.join('solutions',args.artifact + '.zip')
         download_solution(args.artifact,args.version)
+    elif args.artifact_type == 'menu_panel' :
+        pass
     else :
         target = [args.artifact_type]
         if args.artifact_type == 'all' :
@@ -99,6 +100,12 @@ def main() :
         elif args.artifact == '.' or args.artifact == '*':
             target = [(args.artifact_type,path.join(args.artifact_type,args.artifact_type + '.tgz'))]
         else :
+            args.artifact = args.artifact.replace('.',path.sep)
+            if path.sep in args.artifact :
+                parentdir = args.artifact.split(path.sep)[0]
+                if not path.isdir(path.join(args.artifact_type,parentdir)):
+                    mkdir(path.join(args.artifact_type,parentdir))
+
             target = [(args.artifact_type,path.join(args.artifact_type,args.artifact + '.tgz'))]
 
         for t in target :
@@ -107,6 +114,8 @@ def main() :
                 logging.info(f'Extract \'{t[1]}\' to: {t[0]}')
                 tar.extractall(path=t[0],members=change_target_dir(t[0],tar))
 
+                #toggle_mockapi(comment=False)
+
     if args.gitcommit :
 
         folder = path.join(args.artifact_type,args.artifact)
