@@ -7,15 +7,13 @@
 # URL: https://help.sap.com/viewer/0b99871a1d994d2ea89598fe59d16cf9/3.0.2/en-US/38f6d81551c44f5da0f10bd0249d67f1.html#loio38f6d81551c44f5da0f10bd0249d67f1
 
 
-import csv
-from pprint import pprint
 from subprocess import check_output, run
 import logging
 
 import yaml
 
 from diadmin.vctl_cmds.login import di_login
-from genpwds import gen_pwd
+from diadmin.utils.genpwds import gen_pwd
 
 
 # create user from userlist
